@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *  Authors: Alexander Larsson <alexl@redhat.com>
  *
@@ -28,15 +28,25 @@
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <mateconf/mateconf-client.h>
+#include <gio/gio.h>
 #include <unique/uniqueapp.h>
 
 #include "user_share-private.h"
 
 #define REALM "Please log in as the user guest"
 #define USER "guest"
+#define GSETTINGS_SCHEMA "org.mate.FileSharing"
+#define GSETTINGS_KEY_FILE_SHARING_ENABLED "enabled"
+#define GSETTINGS_KEY_FILE_SHARING_BLUETOOTH_ENABLED "bluetooth-enabled"
+#define GSETTINGS_KEY_FILE_SHARING_REQUIRE_PASSWORD "require-password"
+#define GSETTINGS_KEY_FILE_SHARING_BLUETOOTH_ALLOW_WRITE "bluetooth-allow-write"
+#define GSETTINGS_KEY_FILE_SHARING_BLUETOOTH_REQUIRE_PAIRING "bluetooth-require-pairing"
+#define GSETTINGS_KEY_FILE_SHARING_BLUETOOTH_OBEXPUSH_ENABLED "bluetooth-obexpush-enabled"
+#define GSETTINGS_KEY_FILE_SHARING_BLUETOOTH_OBEXPUSH_ACCEPT_FILES "bluetooth-accept-files"
+#define GSETTINGS_KEY_FILE_SHARING_BLUETOOTH_OBEXPUSH_NOTIFY "bluetooth-notify"
 
 static GtkBuilder* builder;
+static GSettings* settings;
 
 
 static void
@@ -85,60 +95,68 @@ flush_password (void)
 static void
 update_ui (void)
 {
-    MateConfClient *client;
-    gboolean enabled, bluetooth_enabled, bluetooth_write_enabled, require_pairing_enabled;
+    GSettings *settings;
+    gboolean enabled;
+#ifdef HAVE_BLUETOOTH
+    gboolean bluetooth_enabled, bluetooth_write_enabled, require_pairing_enabled;
     gboolean bluetooth_obexpush_enabled, bluetooth_obexpush_notify;
+#endif /* HAVE_BLUETOOTH */
     char *str;
     PasswordSetting password_setting;
     AcceptSetting accept_setting;
     GtkWidget *check;
     GtkWidget *password_combo;
     GtkWidget *password_entry;
+#ifdef HAVE_BLUETOOTH
+    GtkWidget *vbox_share_bluetooth;
+    GtkWidget *vbox_receive_bluetooth;
     GtkWidget *bluetooth_check;
     GtkWidget *allow_write_bluetooth_check;
     GtkWidget *require_pairing_check;
     GtkWidget *enable_obexpush_check;
     GtkWidget *accept_obexpush_combo;
     GtkWidget *notify_received_obexpush_check;
+#endif /* HAVE_BLUETOOTH */
 
-    client = mateconf_client_get_default ();
+    settings = g_settings_new (GSETTINGS_SCHEMA);
 
-    enabled = mateconf_client_get_bool (client,
-				     FILE_SHARING_ENABLED,
-				     NULL);
-    bluetooth_enabled = mateconf_client_get_bool (client,
-    					       FILE_SHARING_BLUETOOTH_ENABLED,
-    					       NULL);
-    bluetooth_write_enabled = mateconf_client_get_bool (client,
-						     FILE_SHARING_BLUETOOTH_ALLOW_WRITE,
-						     NULL);
-    require_pairing_enabled = mateconf_client_get_bool (client,
-    						     FILE_SHARING_BLUETOOTH_REQUIRE_PAIRING,
-    						     NULL);
-    bluetooth_obexpush_enabled = mateconf_client_get_bool (client,
-    							FILE_SHARING_BLUETOOTH_OBEXPUSH_ENABLED,
-    							NULL);
-    bluetooth_obexpush_notify = mateconf_client_get_bool (client,
-    						       FILE_SHARING_BLUETOOTH_OBEXPUSH_NOTIFY,
-    						       NULL);
+    enabled = g_settings_get_boolean (settings,
+				     FILE_SHARING_ENABLED);
 
-    str = mateconf_client_get_string (client, FILE_SHARING_REQUIRE_PASSWORD, NULL);
+    str = g_settings_get_string (settings, FILE_SHARING_REQUIRE_PASSWORD);
     password_setting = password_setting_from_string (str);
     g_free (str);
 
-    str = mateconf_client_get_string (client, FILE_SHARING_BLUETOOTH_OBEXPUSH_ACCEPT_FILES, NULL);
+#ifdef HAVE_BLUETOOTH
+    bluetooth_enabled = g_settings_get_boolean (settings,
+    					       FILE_SHARING_BLUETOOTH_ENABLED);
+    bluetooth_write_enabled = g_settings_get_boolean (settings,
+						     FILE_SHARING_BLUETOOTH_ALLOW_WRITE);
+    require_pairing_enabled = g_settings_get_boolean (settings,
+    						     FILE_SHARING_BLUETOOTH_REQUIRE_PAIRING);
+    bluetooth_obexpush_enabled = g_settings_get_boolean (settings,
+    							FILE_SHARING_BLUETOOTH_OBEXPUSH_ENABLED);
+    bluetooth_obexpush_notify = g_settings_get_boolean (settings,
+    						       FILE_SHARING_BLUETOOTH_OBEXPUSH_NOTIFY);
+
+    str = g_settings_get_string (settings, FILE_SHARING_BLUETOOTH_OBEXPUSH_ACCEPT_FILES);
     accept_setting = accept_setting_from_string (str);
     g_free (str);
+#endif /* HAVE_BLUETOOTH */
 
     check = GTK_WIDGET (gtk_builder_get_object (builder, "enable_check"));
     password_combo = GTK_WIDGET (gtk_builder_get_object (builder, "password_combo"));
     password_entry = GTK_WIDGET (gtk_builder_get_object (builder, "password_entry"));
+#ifdef HAVE_BLUETOOTH
+    vbox_share_bluetooth = GTK_WIDGET (gtk_builder_get_object (builder, "vbox_share_bluetooth"));
+    vbox_receive_bluetooth = GTK_WIDGET (gtk_builder_get_object (builder, "vbox_receive_bluetooth"));
     bluetooth_check = GTK_WIDGET (gtk_builder_get_object (builder, "enable_bluetooth_check"));
     allow_write_bluetooth_check = GTK_WIDGET (gtk_builder_get_object (builder, "allow_write_bluetooth_check"));
     require_pairing_check = GTK_WIDGET (gtk_builder_get_object (builder, "require_pairing_check"));
     enable_obexpush_check = GTK_WIDGET (gtk_builder_get_object (builder, "enable_obexpush_check"));
     accept_obexpush_combo = GTK_WIDGET (gtk_builder_get_object (builder, "accept_obexpush_combo"));
     notify_received_obexpush_check = GTK_WIDGET (gtk_builder_get_object (builder, "notify_received_obexpush_check"));
+#endif /* HAVE_BLUETOOTH */
 
     /* Network */
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), enabled);
@@ -148,7 +166,9 @@ update_ui (void)
     gtk_combo_box_set_active (GTK_COMBO_BOX (password_combo),
 			      password_setting);
 
+#ifdef HAVE_BLUETOOTH
     /* Bluetooth ObexFTP */
+    gtk_widget_set_visible (vbox_share_bluetooth, TRUE);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bluetooth_check), bluetooth_enabled);
     gtk_widget_set_sensitive (allow_write_bluetooth_check, bluetooth_enabled);
     gtk_widget_set_sensitive (require_pairing_check, bluetooth_enabled);
@@ -159,6 +179,7 @@ update_ui (void)
     				  require_pairing_enabled);
 
     /* Bluetooth ObexPush */
+    gtk_widget_set_visible (vbox_receive_bluetooth, TRUE);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (enable_obexpush_check), bluetooth_obexpush_enabled);
     gtk_widget_set_sensitive (accept_obexpush_combo, bluetooth_obexpush_enabled);
     gtk_widget_set_sensitive (notify_received_obexpush_check, bluetooth_obexpush_enabled);
@@ -168,158 +189,121 @@ update_ui (void)
 
     gtk_combo_box_set_active (GTK_COMBO_BOX (accept_obexpush_combo),
     			      accept_setting);
+#endif /* HAVE_BLUETOOTH */
 
-    g_object_unref (client);
+    g_object_unref (settings);
 }
 
 static void
-file_sharing_enabled_changed (MateConfClient* client,
-			      guint cnxn_id,
-			      MateConfEntry *entry,
-			      gpointer data)
+file_sharing_enabled_changed (GSettings *settings, gchar *key, gpointer data)
 {
     update_ui ();
 }
 
 static void
-password_required_changed (MateConfClient* client,
-			   guint cnxn_id,
-			   MateConfEntry *entry,
-			   gpointer data)
+password_required_changed (GSettings *settings, gchar *key, gpointer data)
 {
     update_ui ();
 }
 
+#ifdef HAVE_BLUETOOTH
 static void
-file_sharing_bluetooth_enabled_changed (MateConfClient* client,
-					guint cnxn_id,
-					MateConfEntry *entry,
-					gpointer data)
+file_sharing_bluetooth_enabled_changed (GSettings *settings, gchar *key, gpointer data)
 {
 	update_ui ();
 }
 
 static void
-file_sharing_bluetooth_allow_write_changed (MateConfClient* client,
-					    guint cnxn_id,
-					    MateConfEntry *entry,
-					    gpointer data)
+file_sharing_bluetooth_allow_write_changed (GSettings *settings, gchar *key, gpointer data)
 {
 	update_ui ();
 }
 
 static void
-file_sharing_bluetooth_require_pairing_changed (MateConfClient* client,
-						guint cnxn_id,
-						MateConfEntry *entry,
-						gpointer data)
+file_sharing_bluetooth_require_pairing_changed (GSettings *settings, gchar *key, gpointer data)
 {
 	update_ui ();
 }
 
 static void
-file_sharing_bluetooth_obexpush_enabled_changed (MateConfClient* client,
-						 guint cnxn_id,
-						 MateConfEntry *entry,
-						 gpointer data)
+file_sharing_bluetooth_obexpush_enabled_changed (GSettings *settings, gchar *key, gpointer data)
 {
 	update_ui ();
 }
 
 static void
-file_sharing_bluetooth_obexpush_accept_files_changed (MateConfClient* client,
-						      guint cnxn_id,
-						      MateConfEntry *entry,
-						      gpointer data)
+file_sharing_bluetooth_obexpush_accept_files_changed (GSettings *settings, gchar *key, gpointer data)
 {
 	update_ui ();
 }
 
 static void
-file_sharing_bluetooth_obexpush_notify_changed (MateConfClient* client,
-						guint cnxn_id,
-						MateConfEntry *entry,
-						gpointer data)
+file_sharing_bluetooth_obexpush_notify_changed (GSettings *settings, gchar *key, gpointer data)
 {
 	update_ui ();
 }
+#endif /* HAVE_BLUETOOTH */
 
 static void
 password_combo_changed (GtkComboBox *combo_box)
 {
-    MateConfClient *client;
+    GSettings *settings;
     guint setting;
 
     setting = gtk_combo_box_get_active (combo_box);
 
-    client = mateconf_client_get_default ();
+    settings = g_settings_new (GSETTINGS_SCHEMA) ;
 
-    mateconf_client_set_string (client,
+    g_settings_set_string (settings,
 			     FILE_SHARING_REQUIRE_PASSWORD,
-			     password_string_from_setting (setting),
-			     NULL);
-    g_object_unref (client);
+			     password_string_from_setting (setting));
+    g_object_unref (settings);
 }
 
 static void
 launch_share (void)
 {
-	char *argv[2];
-	int i;
-
-	i = 0;
-	argv[i++] = USER_SHARE_PROGRAM;
-	argv[i++] = NULL;
-
-	if (!g_spawn_async (NULL,
-			    argv,
-			    NULL,
-			    0, /* G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL */
-			    NULL,
-			    NULL,
-			    NULL,
-			    NULL)) {
+	if (!g_spawn_command_line_async (USER_SHARE_PROGRAM, NULL))
 		g_warning ("Unable to start mate-user-share program");
-	}
 }
 
+#ifdef HAVE_BLUETOOTH
 static void
 enable_bluetooth_check_toggled (GtkWidget *check)
 {
-	MateConfClient *client;
+	GSettings *settings;
 	gboolean enabled;
 
 	enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
 
-	client = mateconf_client_get_default ();
+	settings = g_settings_new (GSETTINGS_SCHEMA) ;
 
-	mateconf_client_set_bool (client,
+	g_settings_set_boolean (settings,
 			       FILE_SHARING_BLUETOOTH_ENABLED,
-			       enabled,
-			       NULL);
+			       enabled);
 
-	g_object_unref (client);
+	g_object_unref (settings);
 
 	if (enabled != FALSE)
 		launch_share ();
 }
+#endif /* HAVE_BLUETOOTH */
 
 static void
 enable_check_toggled (GtkWidget *check)
 {
-	MateConfClient *client;
+	GSettings *settings;
 	gboolean enabled;
 
 	enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
 
-	client = mateconf_client_get_default ();
+	settings = g_settings_new (GSETTINGS_SCHEMA);
 
-	mateconf_client_set_bool (client,
+	g_settings_set_boolean (settings,
 			       FILE_SHARING_ENABLED,
-			       enabled,
-			       NULL);
+			       enabled);
 
-	g_object_unref (client);
+	g_object_unref (settings);
 
 	if (enabled != FALSE)
 		launch_share ();
@@ -333,58 +317,56 @@ password_entry_changed (GtkEditable *editable)
 	flush_password ();
 }
 
+#ifdef HAVE_BLUETOOTH
 static void
 bluetooth_allow_write_check_toggled (GtkWidget *check)
 {
-	MateConfClient *client;
+	GSettings *settings;
 	gboolean enabled;
 
 	enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
 
-	client = mateconf_client_get_default ();
+	settings = g_settings_new (GSETTINGS_SCHEMA) ;
 
-	mateconf_client_set_bool (client,
+	g_settings_set_boolean (settings,
 			       FILE_SHARING_BLUETOOTH_ALLOW_WRITE,
-			       enabled,
-			       NULL);
+			       enabled);
 
-	g_object_unref (client);
+	g_object_unref (settings);
 }
 
 static void
 bluetooth_require_pairing_check_toggled (GtkWidget *check)
 {
-	MateConfClient *client;
+	GSettings *settings;
 	gboolean enabled;
 
 	enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
 
-	client = mateconf_client_get_default ();
+	settings = g_settings_new (GSETTINGS_SCHEMA) ;
 
-	mateconf_client_set_bool (client,
+	g_settings_set_boolean (settings,
 			       FILE_SHARING_BLUETOOTH_REQUIRE_PAIRING,
-			       enabled,
-			       NULL);
+			       enabled);
 
-	g_object_unref (client);
+	g_object_unref (settings);
 }
 
 static void
 enable_obexpush_check_toggled (GtkWidget *check)
 {
-	MateConfClient *client;
+	GSettings *settings;
 	gboolean enabled;
 
 	enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
 
-	client = mateconf_client_get_default ();
+	settings = g_settings_new (GSETTINGS_SCHEMA) ;
 
-	mateconf_client_set_bool (client,
+	g_settings_set_boolean (settings,
 			       FILE_SHARING_BLUETOOTH_OBEXPUSH_ENABLED,
-			       enabled,
-			       NULL);
+			       enabled);
 
-	g_object_unref (client);
+	g_object_unref (settings);
 
 	if (enabled != FALSE)
 		launch_share ();
@@ -393,37 +375,36 @@ enable_obexpush_check_toggled (GtkWidget *check)
 static void
 accept_obexpush_combo_changed (GtkComboBox *combo_box)
 {
-    MateConfClient *client;
+    GSettings *settings;
     guint setting;
 
     setting = gtk_combo_box_get_active (combo_box);
 
-    client = mateconf_client_get_default ();
+    settings = g_settings_new (GSETTINGS_SCHEMA) ;
 
-    mateconf_client_set_string (client,
+    g_settings_set_string (settings,
 			     FILE_SHARING_BLUETOOTH_OBEXPUSH_ACCEPT_FILES,
-			     accept_string_from_setting (setting),
-			     NULL);
-    g_object_unref (client);
+			     accept_string_from_setting (setting));
+    g_object_unref (settings);
 }
 
 static void
 notify_received_obexpush_check_toggled (GtkWidget *check)
 {
-	MateConfClient *client;
+	GSettings *settings;
 	gboolean enabled;
 
 	enabled = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
 
-	client = mateconf_client_get_default ();
+	settings = g_settings_new (GSETTINGS_SCHEMA) ;
 
-	mateconf_client_set_bool (client,
+	g_settings_set_boolean (settings,
 			       FILE_SHARING_BLUETOOTH_OBEXPUSH_NOTIFY,
-			       enabled,
-			       NULL);
+			       enabled);
 
-	g_object_unref (client);
+	g_object_unref (settings);
 }
+#endif /* HAVE_BLUETOOTH */
 
 static GtkWidget *
 error_dialog (const char *title,
@@ -486,16 +467,18 @@ int
 main (int argc, char *argv[])
 {
     GError *error = NULL;
-    MateConfClient *client;
+    GSettings *settings;
     GtkWidget *check;
     GtkWidget *password_combo;
     GtkWidget *password_entry;
+#ifdef HAVE_BLUETOOTH
     GtkWidget *bluetooth_check;
     GtkWidget *bluetooth_allow_write_check;
     GtkWidget *require_pairing_check;
     GtkWidget *enable_obexpush_check;
     GtkWidget *accept_obexpush_combo;
     GtkWidget *notify_received_obexpush_check;
+#endif /* HAVE_BLUETOOTH */
     GtkWidget *window;
     GtkListStore *store;
     GtkCellRenderer *cell;
@@ -535,21 +518,19 @@ main (int argc, char *argv[])
     g_signal_connect (app, "message-received",
 		      G_CALLBACK (message_received_cb), window);
 
-    client = mateconf_client_get_default ();
-    mateconf_client_add_dir (client,
-			  FILE_SHARING_DIR,
-			  MATECONF_CLIENT_PRELOAD_RECURSIVE,
-			  NULL);
+    settings = g_settings_new (GSETTINGS_SCHEMA);
 
     check = GTK_WIDGET (gtk_builder_get_object (builder, "enable_check"));
     password_combo = GTK_WIDGET (gtk_builder_get_object (builder, "password_combo"));
     password_entry = GTK_WIDGET (gtk_builder_get_object (builder, "password_entry"));
+#ifdef HAVE_BLUETOOTH
     bluetooth_check = GTK_WIDGET (gtk_builder_get_object (builder, "enable_bluetooth_check"));
     bluetooth_allow_write_check = GTK_WIDGET (gtk_builder_get_object (builder, "allow_write_bluetooth_check"));
     require_pairing_check = GTK_WIDGET (gtk_builder_get_object (builder, "require_pairing_check"));
     enable_obexpush_check = GTK_WIDGET (gtk_builder_get_object (builder, "enable_obexpush_check"));
     accept_obexpush_combo = GTK_WIDGET (gtk_builder_get_object (builder, "accept_obexpush_combo"));
     notify_received_obexpush_check = GTK_WIDGET (gtk_builder_get_object (builder, "notify_received_obexpush_check"));
+#endif /* HAVE_BLUETOOTH */
 
     store = gtk_list_store_new (1, G_TYPE_STRING);
     gtk_combo_box_set_model (GTK_COMBO_BOX (password_combo),
@@ -579,6 +560,7 @@ main (int argc, char *argv[])
     g_signal_connect (password_entry,
 		      "changed", G_CALLBACK (password_entry_changed), NULL);
 
+#ifdef HAVE_BLUETOOTH
     /* Accept files combo */
     store = gtk_list_store_new (1, G_TYPE_STRING);
     gtk_combo_box_set_model (GTK_COMBO_BOX (accept_obexpush_combo),
@@ -603,6 +585,7 @@ main (int argc, char *argv[])
     			_("Ask"), -1);
 #endif
     g_object_unref (store);
+#endif /* HAVE_BLUETOOTH */
 
     update_ui ();
 
@@ -610,6 +593,7 @@ main (int argc, char *argv[])
 		      "toggled", G_CALLBACK (enable_check_toggled), NULL);
     g_signal_connect (password_combo,
 		      "changed", G_CALLBACK (password_combo_changed), NULL);
+#ifdef HAVE_BLUETOOTH
     g_signal_connect (bluetooth_check,
     		      "toggled", G_CALLBACK (enable_bluetooth_check_toggled), NULL);
     g_signal_connect (bluetooth_allow_write_check,
@@ -622,6 +606,7 @@ main (int argc, char *argv[])
     		      "changed", G_CALLBACK (accept_obexpush_combo_changed), NULL);
     g_signal_connect (notify_received_obexpush_check,
     		      "toggled", G_CALLBACK (notify_received_obexpush_check_toggled), NULL);
+#endif /* HAVE_BLUETOOTH */
 
     g_signal_connect (GTK_WIDGET (gtk_builder_get_object (builder, "close_button")),
 		      "clicked", G_CALLBACK (gtk_main_quit), NULL);
@@ -629,56 +614,34 @@ main (int argc, char *argv[])
 		      "clicked", G_CALLBACK (help_button_clicked),
 		      gtk_builder_get_object (builder, "user_share_dialog"));
 
-    mateconf_client_notify_add (client,
-			     FILE_SHARING_ENABLED,
-			     file_sharing_enabled_changed,
-			     NULL,
-			     NULL,
-			     NULL);
-    mateconf_client_notify_add (client,
-			     FILE_SHARING_REQUIRE_PASSWORD,
-			     password_required_changed,
-			     NULL,
-			     NULL,
-			     NULL);
-    mateconf_client_notify_add (client,
-			     FILE_SHARING_BLUETOOTH_ENABLED,
-			     file_sharing_bluetooth_enabled_changed,
-			     NULL,
-			     NULL,
-			     NULL);
-    mateconf_client_notify_add (client,
-			     FILE_SHARING_BLUETOOTH_ALLOW_WRITE,
-			     file_sharing_bluetooth_allow_write_changed,
-			     NULL,
-			     NULL,
-			     NULL);
-    mateconf_client_notify_add (client,
-			     FILE_SHARING_BLUETOOTH_REQUIRE_PAIRING,
-			     file_sharing_bluetooth_require_pairing_changed,
-			     NULL,
-			     NULL,
-			     NULL);
-    mateconf_client_notify_add (client,
-    			     FILE_SHARING_BLUETOOTH_OBEXPUSH_ENABLED,
-    			     file_sharing_bluetooth_obexpush_enabled_changed,
-    			     NULL,
-    			     NULL,
-    			     NULL);
-    mateconf_client_notify_add (client,
-    			     FILE_SHARING_BLUETOOTH_OBEXPUSH_ACCEPT_FILES,
-    			     file_sharing_bluetooth_obexpush_accept_files_changed,
-    			     NULL,
-    			     NULL,
-    			     NULL);
-    mateconf_client_notify_add (client,
-    			     FILE_SHARING_BLUETOOTH_OBEXPUSH_NOTIFY,
-			     file_sharing_bluetooth_obexpush_notify_changed,
-			     NULL,
-			     NULL,
-			     NULL);
 
-    g_object_unref (client);
+    g_signal_connect (settings,
+			     "changed::" GSETTINGS_KEY_FILE_SHARING_ENABLED,
+			     G_CALLBACK (file_sharing_enabled_changed), NULL);
+    g_signal_connect (settings,
+			     "changed::" GSETTINGS_KEY_FILE_SHARING_REQUIRE_PASSWORD,
+			     G_CALLBACK (password_required_changed), NULL);
+#ifdef HAVE_BLUETOOTH
+    g_signal_connect (settings,
+			     "changed::" GSETTINGS_KEY_FILE_SHARING_BLUETOOTH_ENABLED,
+			     G_CALLBACK (file_sharing_bluetooth_enabled_changed), NULL);
+    g_signal_connect (settings,
+			     "changed::" GSETTINGS_KEY_FILE_SHARING_BLUETOOTH_ALLOW_WRITE,
+			     G_CALLBACK (file_sharing_bluetooth_allow_write_changed), NULL);
+    g_signal_connect (settings,
+			     "changed::" GSETTINGS_KEY_FILE_SHARING_BLUETOOTH_REQUIRE_PAIRING,
+			     G_CALLBACK (file_sharing_bluetooth_require_pairing_changed), NULL);
+    g_signal_connect (settings,
+			     "changed::" GSETTINGS_KEY_FILE_SHARING_BLUETOOTH_OBEXPUSH_ENABLED,
+			     G_CALLBACK (file_sharing_bluetooth_obexpush_enabled_changed), NULL);
+    g_signal_connect (settings,
+			     "changed::" GSETTINGS_KEY_FILE_SHARING_BLUETOOTH_OBEXPUSH_ACCEPT_FILES,
+			     G_CALLBACK (file_sharing_bluetooth_obexpush_accept_files_changed), NULL);
+    g_signal_connect (settings,
+			     "changed::" GSETTINGS_KEY_FILE_SHARING_BLUETOOTH_OBEXPUSH_NOTIFY,
+			     G_CALLBACK (file_sharing_bluetooth_obexpush_notify_changed), NULL);
+#endif /* HAVE_BLUETOOTH */
+
 
     gtk_widget_show (GTK_WIDGET (gtk_builder_get_object (builder, "user_share_dialog")));
     
